@@ -89,12 +89,17 @@ double ext_kalmanfilter(size_t t,
 		bool isFirstTime){
 	
 	int DEBUG_EKF = 0; /*0=false/no; 1=true/yes*/
+	if(DEBUG_EKF){
+		MYPRINT("Called ext_kalmanfilter\n");
+	}
 	
 	double det;
 	size_t nx=eta_t->size;
 	
 	size_t i,j;
 	
+	/*NB ext_kalmanfilter_smoother() has innov_cov passed to it rather than allocating it*/
+	
 	/* Allocate matrix pointers */
 	gsl_matrix *H_t_plus_1=gsl_matrix_calloc(y_t_plus_1->size, nx);
 	gsl_matrix *ph=gsl_matrix_calloc(eta_t->size, y_t_plus_1->size); /* P*H' - error_cov*jacob'*/
@@ -127,6 +132,9 @@ double ext_kalmanfilter(size_t t,
 		MYPRINT("\n");
 	}
 	
+	/*NB ext_kalmanfilter_smoother() also memcpy's eta_t_plus_1
+	  Add if(isFirstTime || isSmoother ){} */
+	
 	if(isFirstTime){
 		gsl_vector_memcpy(eta_t_plus_1,eta_t);
 	} else{
@@ -153,7 +161,7 @@ double ext_kalmanfilter(size_t t,
 	/*------------------------------------------------------*\
 	* update P *
 	\*------------------------------------------------------*/
-	if (!isFirstTime & isContinuousTime){
+	if (!isFirstTime & isContinuousTime){ /*NB ((!isFirstTime || isSmoother) & isContinuousTime)*/
 		
 		gsl_vector *Pnewvec = gsl_vector_calloc(nx*(nx+1)/2);
 		gsl_vector *error_cov_t_vec = gsl_vector_calloc(nx*(nx+1)/2);
@@ -230,6 +238,7 @@ double ext_kalmanfilter(size_t t,
 		gsl_vector_free(Pnewvec);
 		
 	} else if(!isFirstTime & !isContinuousTime) { /* end continuous time "Update P" calculation */
+		/*NB if((!isFirstTime || isSmoother) & !isContinuousTime)*/
 		
 		/*Update P for discrete time*/
 		gsl_matrix *jacob_dynam = gsl_matrix_calloc(nx,nx);
@@ -257,6 +266,9 @@ double ext_kalmanfilter(size_t t,
 	
 	/** step 2.1: compute measurement y_hat(t+1|t) **/
 	
+	/*NB following line is in smoother but not here*/
+	//    gsl_matrix_memcpy(error_cov_pred,error_cov_t_plus_1);
+	
 	if(DEBUG_EKF){
 		MYPRINT("eta(%d):",t);
 		print_vector(eta_t_plus_1);
@@ -281,29 +293,33 @@ double ext_kalmanfilter(size_t t,
 		print_matrix(error_cov_t_plus_1);
 		MYPRINT("\n");
 	}
-	/*
-	MYPRINT("Hk:\n");
-	print_matrix(H_t_plus_1);
-	MYPRINT("\n");
-	MYPRINT("ph:\n");
-	print_matrix(ph);
-	MYPRINT("\n");
-	*/
+	if(DEBUG_EKF){
+		MYPRINT("Hk:\n");
+		print_matrix(H_t_plus_1);
+		MYPRINT("\n");
+		MYPRINT("ph:\n");
+		print_matrix(ph);
+		MYPRINT("\n");
+	}
 	
 	gsl_blas_dgemm(CblasNoTrans, CblasNoTrans, 1.0, H_t_plus_1, ph, 0.0, innov_cov); /* compute H*P*H'*/
-	/*MYPRINT("jacob_measure:\n");
-	print_matrix(jacob_measure);
-	MYPRINT("\n");*/
-	/*MYPRINT("ph:\n");
-	print_matrix(ph);
-	MYPRINT("\n");*/
+	if(DEBUG_EKF){
+		/*MYPRINT("jacob_measure:\n");
+		print_matrix(jacob_measure);
+		MYPRINT("\n");*/
+		MYPRINT("ph:\n");
+		print_matrix(ph);
+		MYPRINT("\n");
+	}
 	/*mathfunction_matrix_mul(jacob_measure, ph, false, false, innov_cov);*/
 	
-	/*MYPRINT("H*P(%d)*H':\n", t);
-	print_matrix(innov_cov);
-	MYPRINT("R(%d):\n", t);
-	print_matrix(y_noise_cov);
-	MYPRINT("\n");*/
+	if(DEBUG_EKF){
+		MYPRINT("H*P(%d)*H':\n", t);
+		print_matrix(innov_cov);
+		MYPRINT("R(%d):\n", t);
+		print_matrix(y_noise_cov);
+		MYPRINT("\n");
+	}
 	
 	gsl_matrix_add(innov_cov, y_noise_cov); /*compute H*P*H'+R*/
 	
@@ -323,23 +339,26 @@ double ext_kalmanfilter(size_t t,
 	det = mathfunction_inv_matrix_det(innov_cov, inv_innov_cov);
 	
 	
-	/*MYPRINT("inv_innov_cov:\n");
-	print_matrix(inv_innov_cov);
-	MYPRINT("\n");
-	exit(0);*/
+	if(DEBUG_EKF){
+		MYPRINT("inv_innov_cov:\n");
+		print_matrix(inv_innov_cov);
+		MYPRINT("\n");
+	}
 	
 	gsl_blas_dgemm(CblasNoTrans, CblasNoTrans, 1.0, ph, inv_innov_cov, 0.0, kalman_gain); /* compute P*H*S^{-1}*/
 	
 	
-	/*MYPRINT("ph:\n");
-	print_matrix(ph);
-	MYPRINT("\n");
-	MYPRINT("inverse residu:\n");
-	print_matrix(inv_innov_cov);
-	MYPRINT("\n");
-	MYPRINT("kalman_gain:\n");
-	print_matrix(kalman_gain);
-	MYPRINT("\n");*/
+	if(DEBUG_EKF){
+		MYPRINT("ph:\n");
+		print_matrix(ph);
+		MYPRINT("\n");
+		MYPRINT("inverse residu:\n");
+		print_matrix(inv_innov_cov);
+		MYPRINT("\n");
+		MYPRINT("kalman_gain:\n");
+		print_matrix(kalman_gain);
+		MYPRINT("\n");
+	}
 	
 	/*------------------------------------------------------*\
 	* Fitered Estimate *
@@ -355,13 +374,26 @@ double ext_kalmanfilter(size_t t,
 		if(gsl_vector_get(y_non_miss, i) == 1)
 			continue;
 		gsl_vector_set(innov_v, i, 0);
+		/* Set COLUMN of kalman_gain to zero for missing data */
+		for(size_t j=0; j < kalman_gain->size1; j++){
+			gsl_matrix_set(kalman_gain, j, i, 0);
+		}
+	}
+	
+	if(DEBUG_EKF){
+		MYPRINT("Filtered kalman_gain:\n");
+		print_matrix(kalman_gain);
+		MYPRINT("\n");
 	}
 	
 	gsl_blas_dgemv(CblasNoTrans, 1.0, kalman_gain, innov_v, 1.0, eta_t_plus_1); /* x(k+1|k+1)=x(k+1|k)+W(k+1)*v(k+1)*/
 	
-	/*MYPRINT("eta_corrected(%lf):", y_time[t]);
-	print_vector(eta_t_plus_1);
-	MYPRINT("\n");*/
+	
+	if(DEBUG_EKF){
+		MYPRINT("eta_corrected(%lf):", y_time[t]);
+		print_vector(eta_t_plus_1);
+		MYPRINT("\n");
+	}
 	
 	
 	/*------------------------------------------------------*\
@@ -420,7 +452,7 @@ double ext_kalmanfilter(size_t t,
 	
 	/** free allocated space **/
 	gsl_matrix_free(ph);
-	gsl_matrix_free(innov_cov);
+	gsl_matrix_free(innov_cov); /*NB not freed in ext_kalmanfilter_smoother because it is passed as an argument rather than allocated */
 	gsl_matrix_free(kalman_gain);
 	gsl_matrix_free(H_t_plus_1);
 	gsl_vector_free(cp_y_t_plus_1);
@@ -471,7 +503,7 @@ double ext_kalmanfilter_smoother(size_t t, size_t regime,
 	        void (*g)(double, size_t, double *, const gsl_vector *, gsl_matrix *),
 			gsl_matrix *),
         gsl_vector *eta_pred, gsl_matrix *error_cov_pred, gsl_vector *eta_t_plus_1, gsl_matrix *error_cov_t_plus_1, 
-		gsl_vector *innov_v, gsl_matrix *inv_innov_cov, gsl_matrix *innov_cov){
+		gsl_vector *innov_v, gsl_matrix *inv_innov_cov, gsl_matrix *innov_cov, bool isFirstTime){
 
     double det;
     size_t nx=eta_t->size;
@@ -510,8 +542,11 @@ double ext_kalmanfilter_smoother(size_t t, size_t regime,
     print_array(params,num_func_param);
     MYPRINT("\n");*/
 
-
-    func_dynam(y_time[t-1], y_time[t], regime, eta_t, params, num_func_param, co_variate, func_dx_dt, eta_t_plus_1);
+    if(isFirstTime){
+      gsl_vector_memcpy(eta_t_plus_1,eta_t);
+	} else {
+	    func_dynam(y_time[t-1], y_time[t], regime, eta_t, params, num_func_param, co_variate, func_dx_dt, eta_t_plus_1);
+	}
 
     /*MYPRINT("eta_pred:\n");
     print_vector(eta_t_plus_1);
@@ -531,7 +566,7 @@ double ext_kalmanfilter_smoother(size_t t, size_t regime,
 	/*------------------------------------------------------*\
 	* update P *
 	\*------------------------------------------------------*/
-	if (isContinuousTime){
+	if (!isFirstTime & isContinuousTime){
 		
 	    gsl_vector *Pnewvec=gsl_vector_calloc(nx*(nx+1)/2);
 	    gsl_vector *error_cov_t_vec=gsl_vector_calloc(nx*(nx+1)/2);
@@ -605,7 +640,7 @@ double ext_kalmanfilter_smoother(size_t t, size_t regime,
 	    gsl_vector_free(error_cov_t_vec);
 	    gsl_vector_free(Pnewvec);
 		
-	}else{
+	}else if(!isFirstTime & !isContinuousTime){
 		
 	    gsl_matrix *jacob_dynam=gsl_matrix_calloc(nx,nx);
 	    gsl_matrix *p_jacob_dynam=gsl_matrix_calloc(nx, nx);
@@ -620,6 +655,8 @@ double ext_kalmanfilter_smoother(size_t t, size_t regime,
 		
 		gsl_matrix_free(jacob_dynam);
 		gsl_matrix_free(p_jacob_dynam);
+	} else if(isFirstTime){
+      gsl_matrix_memcpy(error_cov_t_plus_1,error_cov_t);
 	}
 
 
@@ -732,7 +769,11 @@ double ext_kalmanfilter_smoother(size_t t, size_t regime,
 	for(i=0; i<y_non_miss->size; i++){
 		if(gsl_vector_get(y_non_miss, i)==1)
 			continue;
-			gsl_vector_set(innov_v, i, 0); 
+		gsl_vector_set(innov_v, i, 0);
+		/* Set COLUMN of kalman_gain to zero for missing data */
+		for(size_t j=0; j < kalman_gain->size1; j++){
+			gsl_matrix_set(kalman_gain, j, i, 0);
+		}
 	}
 
     gsl_blas_dgemv(CblasNoTrans, 1.0, kalman_gain, innov_v, 1.0, eta_t_plus_1); /* x(k+1|k+1)=x(k+1|k)+W(k+1)*v(k+1)*/
@@ -787,230 +828,4 @@ double ext_kalmanfilter_smoother(size_t t, size_t regime,
     return det;
 }
 
-/** NOTE: This function is the same as
- * ext_kalmanfilter_smoother
- * except that is just copies the 'previous' state forward.
- * This is appropriate for the way dynr handles initial conditions.
- * brekfis calls ext_kalmanfilter_updateonly_smoother for the first time point
- * of every subject but ext_kalmanfilter_smoother for all later time points.
- * These two functions should be merged to eliminate lots of duplicate code.
-**/
-double ext_kalmanfilter_updateonly_smoother(size_t t, size_t regime,
-     gsl_vector *eta_t,  gsl_matrix *error_cov_t,
-	const gsl_vector *y_t_plus_1,const gsl_vector *co_variate, const double *y_time,
-	const gsl_matrix *eta_noise_cov, const gsl_matrix *y_noise_cov,
-        double *params,
-        void (*func_measure)(size_t, size_t, double *, const gsl_vector *, const gsl_vector *, gsl_matrix *, gsl_vector *),
-        gsl_vector *eta_pred, gsl_matrix *error_cov_pred, gsl_vector *eta_t_plus_1, gsl_matrix *error_cov_t_plus_1, 
-		gsl_vector *innov_v, gsl_matrix *inv_innov_cov, gsl_matrix *innov_cov){
 
-    double det;
-	size_t i;
-    size_t nx=eta_t->size;
-
-    gsl_matrix *H_t_plus_1=gsl_matrix_calloc(y_t_plus_1->size,nx);
-
-
-    gsl_matrix *ph=gsl_matrix_calloc(eta_t->size, y_t_plus_1->size); /* P*H' - error_cov*jacob'*/
-    
-    gsl_matrix *kalman_gain=gsl_matrix_calloc(eta_t->size, y_t_plus_1->size);
-
-    /** handling missing data **/
-    gsl_vector *cp_y_t_plus_1=gsl_vector_alloc(y_t_plus_1->size);
-    gsl_vector_memcpy(cp_y_t_plus_1, y_t_plus_1);
-	
-	
-	
-    gsl_vector *y_non_miss=gsl_vector_alloc(y_t_plus_1->size);
-    size_t miss_case=find_miss_data(cp_y_t_plus_1, y_non_miss); /* 0 - no miss, 1 - part miss, 2 - all miss*/
-	gsl_vector *zero_eta=gsl_vector_calloc(eta_t->size);
-
-    /*------------------------------------------------------*\
-    * update xk *
-    \*------------------------------------------------------*/
-      gsl_vector_memcpy(eta_t_plus_1,eta_t);
-      gsl_vector_memcpy(eta_pred,eta_t_plus_1);
-
-    /*MYPRINT("y_time:\n");
-    MYPRINT("%f ",y_time[t-1]);
-    MYPRINT("%f",y_time[t]);
-    MYPRINT("\n");
-    MYPRINT("regime: %lu\n",regime);
-    MYPRINT("eta_previous:\n");
-    print_vector(eta_t);
-    MYPRINT("\n");
-    MYPRINT("error_cov_previous:\n");
-    print_matrix(error_cov_t);
-    MYPRINT("\n");
-    MYPRINT("parameters:\n");
-    print_array(params,11);
-    MYPRINT("\n");*/
-      /*------------------------------------------------------*\
-      * update P *
-      \*------------------------------------------------------*/
-      gsl_matrix_memcpy(error_cov_t_plus_1,error_cov_t);
-      gsl_matrix_memcpy(error_cov_pred,error_cov_t_plus_1);
-
-      /*------------------------------------------------------*\
-      * innovation vector-- will be used to calculate loglikelihood*
-      \*------------------------------------------------------*/
-
-      /** step 2.1: compute measurement y_hat(t+1|t) **/
-      
-          /*MYPRINT("eta(%d):",t_plus_1);
-          print_vector(eta_t_plus_1);
-          MYPRINT("\n");*/
-          func_measure(t, regime, params, eta_t_plus_1, co_variate, H_t_plus_1, innov_v);
-	
-      /*MYPRINT("y_hat(%d):", t_plus_1);
-      print_vector(innov_v);
-      MYPRINT("\n");*/
-
-      /*------------------------------------------------------*\
-      * innovation variance--------Rek=Rk+H_t_plus_1%*%Pnew%*%t(H_t_plus_1) -- will be used to calculate loglikelihood*
-      \*------------------------------------------------------*/
-
-      gsl_blas_dgemm(CblasNoTrans, CblasTrans, 1.0, error_cov_t_plus_1, H_t_plus_1, 0.0, ph); /* compute P*H'*/
-      /*mathfunction_matrix_mul(error_cov_t_plus_1, jacob_measure, false, true, ph);*/
-
-      /*if(t==0){
-          MYPRINT("error_cov(%lu):\n", t);
-          print_matrix(error_cov_t_plus_1);
-          MYPRINT("\n");
-          MYPRINT("Hk:\n");
-          print_matrix(H_t_plus_1);
-          MYPRINT("\n");
-          MYPRINT("ph:\n");
-          print_matrix(ph);
-          MYPRINT("\n");
-      }*/
-
-      gsl_blas_dgemm(CblasNoTrans, CblasNoTrans, 1.0, H_t_plus_1, ph, 0.0, innov_cov); /* compute H*P*H'*/
-      /*MYPRINT("jacob_measure:\n");
-      print_matrix(jacob_measure);
-      MYPRINT("\n");
-      MYPRINT("ph:\n");
-      print_matrix(ph);
-      MYPRINT("\n");*/
-      /*mathfunction_matrix_mul(jacob_measure, ph, false, false, innov_cov);*/
-
-      /*MYPRINT("y_cov(%d):\n", t_plus_1);
-      print_matrix(innov_cov);
-      MYPRINT("\n");*/
-
-
-
-      gsl_matrix_add(innov_cov, y_noise_cov); /*compute H*P*H'+R*/
-
-      /*print_matrix(y_noise_cov);
-      print_matrix(innov_cov);
-                   MYPRINT("\n");*/
-
-
-      /*------------------------------------------------------*\
-      * Kalman Gain------Kk=Pnew%*%t(H_t_plus_1)%*%solve(Rek) *
-      \*------------------------------------------------------*/
-
-
-      	det=mathfunction_inv_matrix_det(innov_cov, inv_innov_cov);
-
-
-
-          /*MYPRINT("inv_innov_cov:\n");
-          print_matrix(inv_innov_cov);
-          MYPRINT("\n");
-          exit(0);*/
-
-          gsl_blas_dgemm(CblasNoTrans, CblasNoTrans, 1.0, ph, inv_innov_cov, 0.0, kalman_gain); /* compute P*H*S^{-1}*/
-
-
-          /*MYPRINT("ph:\n");
-          print_matrix(ph);
-          MYPRINT("\n");
-          MYPRINT("inverse residu:\n");
-          print_matrix(inv_innov_cov);
-          MYPRINT("\n");
-          MYPRINT("kalman_gain:\n");
-          print_matrix(kalman_gain);
-          MYPRINT("\n");*/
-
-      /*------------------------------------------------------*\
-      * Fitered Estimate *
-      \*------------------------------------------------------*/
-
-
-
-      /** step 2.2: compute prediction residual y-y_hat **/
-      gsl_vector_sub(innov_v, cp_y_t_plus_1);
-      gsl_vector_scale(innov_v, -1); /* now innov_v stores the residual, i.e, v(t+1)*/
-	  /*handling missing data*/
-	  for(i=0; i<y_non_miss->size; i++){
-		  if(gsl_vector_get(y_non_miss, i)==1)
-			  continue;
-		  gsl_vector_set(innov_v, i, 0); 
-  	  }
-	  
-
-
-      gsl_blas_dgemv(CblasNoTrans, 1.0, kalman_gain, innov_v, 1.0, eta_t_plus_1); /* x(k+1|k+1)=x(k+1|k)+W(k+1)*v(k+1)*/
-
-
-      /*------------------------------------------------------*\
-      * Filtered Error Cov Matrix *
-      \*------------------------------------------------------*/
-      /*P_kplus1=Pnew-Kk%*%H_t_plus_1%*%Pnew
-      P[,k]=c(P_kplus1[1,1],P_kplus1[2,2],P_kplus1[3,3],P_kplus1[1,2],P_kplus1[1,3],P_kplus1[2,3])*/
-
-
-       /*MYPRINT("ph:\n");
-      print_matrix(ph);
-      MYPRINT("\n");
-      MYPRINT("kalman_gain:\n");
-      print_matrix(kalman_gain);
-      MYPRINT("\n");
-      MYPRINT("error_cov(%d):\n", t_plus_1);
-      print_matrix(Pnew);
-      MYPRINT("\n");*/
-      /*if(miss_case==1){
-          for(i=0; i<y_non_miss->size; i++){
-              if(gsl_vector_get(y_non_miss, i)==1)
-                  continue;
-              gsl_matrix_set_col(ph, i, zero_eta); 
-          }
-      }*/
-
-      gsl_blas_dgemm(CblasNoTrans, CblasTrans, 1.0, ph, kalman_gain, -1.0, error_cov_t_plus_1); /* W*S*W'-P=P*H'*W'-P=Pnew*H_t_plus_1'*Kk'-Pnew*/
-
-
-
-      gsl_matrix_scale(error_cov_t_plus_1, -1.0); /* compute P-W*S*W'*/
-
-          /*MYPRINT("error_cov_corrected(%lf):", y_time[t]);
-          print_matrix(error_cov_t_plus_1);
-          MYPRINT("\n");*/
-	  /*if(miss_case!=0){
-          MYPRINT("innov_v(%lf)", y_time[t]);
-          print_vector(innov_v);
-          MYPRINT("\n");
-	      MYPRINT("inv_innov_cov(%lf):\n", y_time[t]);
-	      print_matrix(inv_innov_cov);
-	      MYPRINT("\n");
-          MYPRINT("eta_corrected(%lf):", y_time[t]);
-          print_vector(eta_t_plus_1);
-          MYPRINT("\n");
-	      MYPRINT("error_cov_corrected(%lf):\n", y_time[t]);
-	      print_matrix(error_cov_t_plus_1);
-	      MYPRINT("\n");
-	  }*/
-
-      /** free allocated space **/
-      gsl_matrix_free(ph);
-
-      gsl_matrix_free(kalman_gain);
-      gsl_matrix_free(H_t_plus_1);
-      gsl_vector_free(cp_y_t_plus_1);
-	  
-      gsl_vector_free(zero_eta);
-      gsl_vector_free(y_non_miss);
-    return det;
-}
